from importlib.metadata import version

from .s1_orbits import fetch_for_scene, API_URL
from .exceptions import InvalidSceneError, OrbitNotFoundError

__version__ = version(__name__)

__all__ = [
    "__version__",
    "fetch_for_scene",
    "API_URL",
    "InvalidSceneError",
    "OrbitNotFoundError",
]



class InvalidSceneError(Exception):
    def __init__(self, scene: str):
        self.scene = scene
        self.message = f"{scene} is not a valid Sentinel-1 scene name."

    def __str__(self):
        return str(self.message)


class OrbitNotFoundError(Exception):
    def __init__(self, scene: str):
        self.scene = scene
        self.message = (
            f"No orbit file could be found for the provided Sentinel-1 scene: {scene}"
        )

    def __str__(self):
        return str(self.message)



import responses
import pytest
from pathlib import Path

import s1_orbits


@responses.activate
def test_fetch_for_scene(tmp_path):
    granule = "foo"
    filename = "filename.txt"
    file_contents = "This is some text."
    request_url = f"{s1_orbits.API_URL}/{granule}"
    response_url = f"https://bar.com/{filename}"

    responses.add(
        responses.GET, request_url, status=302, headers={"Location": response_url}
    )
    responses.add(
        responses.GET,
        response_url,
        status=200,
        body=file_contents,
        content_type="text/plain",
    )
    filepath = s1_orbits.fetch_for_scene(granule, tmp_path)
    assert filepath == Path(tmp_path) / filename
    assert filepath.read_text() == file_contents

    responses.add(responses.GET, request_url, status=400)
    with pytest.raises(s1_orbits.InvalidSceneError) as invalid_error:
        s1_orbits.fetch_for_scene(granule, tmp_path)
        assert invalid_error.scene == granule

    responses.add(responses.GET, request_url, status=404)
    with pytest.raises(s1_orbits.OrbitNotFoundError) as not_found_error:
        s1_orbits.fetch_for_scene(granule, tmp_path)
        assert not_found_error.scene == granule
